==> haskell-stringsearch-0.3.6.6-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-stringsearch.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: stringsearch
version: 0.3.6.6
id: stringsearch-0.3.6.6-DVhPUcSGzzGLKEmt1U9sof
key: stringsearch-0.3.6.6-DVhPUcSGzzGLKEmt1U9sof
license: BSD3
copyright: (c) 2007-2011
           Daniel Fischer, Chris Kuklewicz, Justin Bailey
maintainer: daniel.is.fischer@googlemail.com
homepage: https://bitbucket.org/dafis/stringsearch
synopsis: Fast searching, splitting and replacing of ByteStrings
description:
    This package provides several functions to quickly
    search for substrings in strict or lazy ByteStrings.
    It also provides functions for breaking or splitting
    on substrings and replacing all occurrences of a
    substring (the first in case of overlaps) with another.
    GHC before 6.10 are no longer supported, other compilers
    only if they support BangPatterns. If you need it to
    work with other compilers, send a feature request.
category: Text, Search
author: Daniel Fischer, Chris Kuklewicz, Justin Bailey
exposed: True
exposed-modules:
    Data.ByteString.Search Data.ByteString.Search.BoyerMoore
    Data.ByteString.Search.DFA Data.ByteString.Search.KarpRabin
    Data.ByteString.Search.KMP Data.ByteString.Search.KnuthMorrisPratt
    Data.ByteString.Search.Substitution Data.ByteString.Lazy.Search
    Data.ByteString.Lazy.Search.DFA
    Data.ByteString.Lazy.Search.KarpRabin
    Data.ByteString.Lazy.Search.KMP
hidden-modules: Data.ByteString.Search.Internal.BoyerMoore
                Data.ByteString.Search.Internal.KnuthMorrisPratt
                Data.ByteString.Search.Internal.Utils
                Data.ByteString.Lazy.Search.Internal.BoyerMoore
abi: 37c4863b281615bf6a017bf46d31240e
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/stringsearch-0.3.6.6
library-dirs: /usr/lib/ghc-8.0.1/site-local/stringsearch-0.3.6.6
data-dir: /usr/share/i386-linux-ghc-8.0.1/stringsearch-0.3.6.6
hs-libraries: HSstringsearch-0.3.6.6-DVhPUcSGzzGLKEmt1U9sof
depends:
    array-0.5.1.1 base-4.9.0.0 bytestring-0.10.8.1 containers-0.5.7.1
haddock-interfaces: /usr/share/doc/haskell-stringsearch/html/stringsearch.haddock
haddock-html: /usr/share/doc/haskell-stringsearch/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-stringsearch-0.3.6.6-3-i686.pkg.tar.xz: usr/share/haskell/register/haskell-stringsearch.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: stringsearch
version: 0.3.6.6
id: stringsearch-0.3.6.6-8anNeXolBRk4a9DV14i2Be
key: stringsearch-0.3.6.6-8anNeXolBRk4a9DV14i2Be
license: BSD3
copyright: (c) 2007-2011
           Daniel Fischer, Chris Kuklewicz, Justin Bailey
maintainer: daniel.is.fischer@googlemail.com
homepage: https://bitbucket.org/dafis/stringsearch
synopsis: Fast searching, splitting and replacing of ByteStrings
description:
    This package provides several functions to quickly
    search for substrings in strict or lazy ByteStrings.
    It also provides functions for breaking or splitting
    on substrings and replacing all occurrences of a
    substring (the first in case of overlaps) with another.
    GHC before 6.10 are no longer supported, other compilers
    only if they support BangPatterns. If you need it to
    work with other compilers, send a feature request.
category: Text, Search
author: Daniel Fischer, Chris Kuklewicz, Justin Bailey
exposed: True
exposed-modules:
    Data.ByteString.Search Data.ByteString.Search.BoyerMoore
    Data.ByteString.Search.DFA Data.ByteString.Search.KarpRabin
    Data.ByteString.Search.KMP Data.ByteString.Search.KnuthMorrisPratt
    Data.ByteString.Search.Substitution Data.ByteString.Lazy.Search
    Data.ByteString.Lazy.Search.DFA
    Data.ByteString.Lazy.Search.KarpRabin
    Data.ByteString.Lazy.Search.KMP
hidden-modules: Data.ByteString.Search.Internal.BoyerMoore
                Data.ByteString.Search.Internal.KnuthMorrisPratt
                Data.ByteString.Search.Internal.Utils
                Data.ByteString.Lazy.Search.Internal.BoyerMoore
abi: f814b487737bea407e7c9b6401d98520
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/stringsearch-0.3.6.6
library-dirs: /usr/lib/ghc-8.0.2/site-local/stringsearch-0.3.6.6
dynamic-library-dirs: /usr/lib/i386-linux-ghc-8.0.2
data-dir: /usr/share/i386-linux-ghc-8.0.2/stringsearch-0.3.6.6
hs-libraries: HSstringsearch-0.3.6.6-8anNeXolBRk4a9DV14i2Be
depends:
    array-0.5.1.1 base-4.9.1.0 bytestring-0.10.8.1 containers-0.5.7.1
haddock-interfaces: /usr/share/doc/haskell-stringsearch/html/stringsearch.haddock
haddock-html: /usr/share/doc/haskell-stringsearch/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
